@@ -22,7 +22,7 @@ waldWR = function(target, dataset, xIndex, csIndex, wei = NULL, univariateModels
   #if the censored indicator is empty, a dummy variable is created
   numCases = dim(dataset)[1];
   if (length(event) == 0)  event = vector('numeric',numCases) + 1;
-      if (is.na(csIndex) || length(csIndex) == 0 || csIndex == 0) {
+      if  ( length(csIndex) == 0 || sum(csIndex == 0, na.rm = TRUE) > 0 ) {
         weibull_results <- survival::survreg( target ~ dataset[, index], weights = wei, control = list(iter.max = 5000) )
         res = summary(weibull_results)[[ 9 ]]
         stat = res[2, 3]^2
