@@ -62,8 +62,6 @@ zip.bsreg <- function(target, dataset, threshold = 0.05, wei = NULL) {
     
     i <- 1  
     
-    if ( info[1, 2] > threshold  &  dim(mat)[1] > 0 ) {
-      
       while ( info[i, 2] > threshold  &  dim(dat)[2] > 0 )  {   
         
         ini <- zip.mod( target, dat, wei = wei )
@@ -117,10 +115,7 @@ zip.bsreg <- function(target, dataset, threshold = 0.05, wei = NULL) {
       runtime <- proc.time() - runtime	
       info <- info[ info[, 1] > 0, , drop = FALSE]
       res <- list(runtime = runtime, info = info, mat = mat, ci_test = "testIndzIP", final = final ) 
-    } else {
-      runtime <- runtime - proc.time()
-      res <- list(runtime = runtime, info = info, mat = NULL, ci_test = "testIndZIP", final = mod ) 
-    }
+
     }  
   }  
   
